@@ -60,7 +60,9 @@ static void default_values (struct starter_config *cfg)
 
 	cfg->setup.options[KBF_FRAGICMP] = TRUE;
 	cfg->setup.options[KBF_HIDETOS]  = TRUE;
-	cfg->setup.options[KBF_UNIQUEIDS]= FALSE;
+	cfg->setup.options[KBF_PLUTORESTARTONCRASH]  = TRUE;
+	cfg->setup.options[KBF_UNIQUEIDS]= TRUE;
+	cfg->setup.options[KBF_DISABLEPORTFLOATING]= FALSE;
 	cfg->conn_default.options[KBF_TYPE] = KS_TUNNEL;
 
 	cfg->conn_default.policy = POLICY_RSASIG|POLICY_TUNNEL|POLICY_ENCRYPT|POLICY_PFS;
@@ -282,6 +284,9 @@ static int load_setup (struct starter_config *cfg
 
 	    case kt_comment:
 		break;
+	    case kt_obsolete:
+	        starter_log(LOG_LEVEL_INFO, "Warning: ignored obsolete keyword %s",kw->string);
+		break;
 	    }
 	}
 		
@@ -733,6 +738,9 @@ bool translate_conn (struct starter_conn *conn
 	    
 	case kt_comment:
 	    break;
+	case kt_obsolete:
+	    starter_log(LOG_LEVEL_DEBUG,"Warning: obsolete keyword %s ignored\n",kw->keyword.keydef->keyname);
+	    break;
 	}
     }
     return err;
