@@ -1,6 +1,7 @@
 /*
  * Openswan config file parser (keywords.c)
  * Copyright (C) 2003-2006 Michael Richardson <mcr@xelerance.com>
+ * Copyright (C) 2007-2008 Paul Wouters <paul@xelerance.com>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -165,6 +166,9 @@ struct keyword_enum_value kw_proto_stack_list[]={
     { "mast",         USE_MASTKLIPS }, 
     { "netkey",       USE_NETKEY },
     { "native",       USE_NETKEY },
+    { "bsd",          USE_BSDKAME },
+    { "kame",         USE_BSDKAME },
+    { "bsdkame",      USE_BSDKAME },
     { "win2k",        USE_WIN2K },
     { "funk",         USE_FUNK },
 };
@@ -185,6 +189,7 @@ struct keyword_enum_value kw_plutodebug_values[]={
     { "all",      DBG_ALL },
     { "raw",      DBG_RAW },
     { "crypt",    DBG_CRYPT },
+    { "crypto",   DBG_CRYPT },
     { "parsing",  DBG_PARSING },
     { "emitting", DBG_EMITTING },
     { "control",  DBG_CONTROL },
@@ -264,7 +269,6 @@ struct keyword_enum_values kw_sendcert_list=
 /* MASTER KEYWORD LIST */
 struct keyword_def ipsec_conf_keywords_v2[]={
     {"interfaces",     kv_config, kt_string,    KSF_INTERFACES,NOT_ENUM},
-    {"forwardcontrol", kv_config, kt_bool,      KBF_FORWARDCONTROL,NOT_ENUM},
     {"myid",           kv_config, kt_string,    KSF_MYID,NOT_ENUM},
     {"syslog",         kv_config, kt_string,    KSF_SYSLOG,NOT_ENUM},
     {"klipsdebug",     kv_config, kt_list,      KBF_KLIPSDEBUG, &kw_klipsdebug_list},
@@ -281,20 +285,24 @@ struct keyword_def ipsec_conf_keywords_v2[]={
     {"postpluto",      kv_config, kt_filename,  KSF_POSTPLUTO,NOT_ENUM},
     {"fragicmp",       kv_config, kt_bool,      KBF_FRAGICMP,NOT_ENUM},
     {"hidetos",        kv_config, kt_bool,      KBF_HIDETOS,NOT_ENUM},
-    {"rp_filter",      kv_config, kt_enum,      KBF_RPFILTER,NOT_ENUM},
     {"uniqueids",      kv_config, kt_bool,      KBF_UNIQUEIDS,NOT_ENUM},
     {"overridemtu",    kv_config, kt_number,    KBF_OVERRIDEMTU,NOT_ENUM},
     {"nocrsend",       kv_config, kt_bool,      KBF_NOCRSEND,NOT_ENUM},
-    {"strictcrlpolicy",kv_config, kt_enum,      KBF_STRICTCRLPOLICY,NOT_ENUM},
+    {"strictcrlpolicy",kv_config, kt_bool,      KBF_STRICTCRLPOLICY,NOT_ENUM},
     {"crlcheckinterval",kv_config,kt_time,      KBF_CRLCHECKINTERVAL,NOT_ENUM},
     {"force_busy",     kv_config, kt_bool,      KBF_FORCEBUSY,NOT_ENUM},
 #ifdef NAT_TRAVERSAL
     {"virtual_private",kv_config,kt_string,     KSF_VIRTUALPRIVATE,NOT_ENUM},
     {"nat_traversal", kv_config,kt_bool,        KBF_NATTRAVERSAL, NOT_ENUM},
+    {"disable_port_floating", kv_config,kt_bool,KBF_DISABLEPORTFLOATING, NOT_ENUM},
 #endif
     {"protostack",     kv_config, kt_string,    KSF_PROTOSTACK, &kw_proto_stack},
     {"nhelpers",kv_config,kt_number, KBF_NHELPERS, NOT_ENUM},
 
+    /* these two options are obsoleted. Don't die on them */
+    {"forwardcontrol", kv_config, kt_obsolete, KBF_WARNIGNORE,NOT_ENUM},
+    {"rp_filter",      kv_config, kt_obsolete, KBF_WARNIGNORE,NOT_ENUM},
+
     /* this is "left=" and "right=" */
     {"",               kv_conn|kv_leftright, kt_loose_enum, KSCF_IP, &kw_host_list},  
 
