@@ -314,7 +314,9 @@ ipsec_xmit_ah_setup(struct ipsec_xmit_state *ixs)
 }
 
 struct xform_functions ah_xform_funcs[]={
-	{	rcv_checks:         ipsec_rcv_ah_checks,
+	{
+		protocol:           IPPROTO_AH,
+		rcv_checks:         ipsec_rcv_ah_checks,
 		rcv_setup_auth:     ipsec_rcv_ah_setup_auth,
 		rcv_calc_auth:      ipsec_rcv_ah_authcalc,
 		rcv_decrypt:        ipsec_rcv_ah_decap,
@@ -350,3 +352,9 @@ struct inet_protocol ah_protocol =
 #endif /* NET_26 */
 #endif /* CONFIG_XFRM_ALTERNATE_STACK */
 
+/*
+ * Local variables:
+ * c-file-style: "linux"
+ * End:
+ *
+ */
