@@ -23,7 +23,7 @@
 #include <linux/module.h>
 #include <linux/version.h>
 #ifndef AUTOCONF_INCLUDED
-#include <linux/config.h>
+# include <linux/config.h>
 #endif
 #include <linux/kernel.h>
 
@@ -49,7 +49,9 @@
 #else /* MALLOC_SLAB */
 # include <linux/malloc.h> /* kmalloc() */
 #endif /* MALLOC_SLAB */
-#include <asm/segment.h>
+#ifdef CONFIG_X86
+# include <asm/segment.h>
+#endif
 #include <linux/skbuff.h>
 #include <linux/netdevice.h>
 #include <net/sock.h> /* struct sock */
@@ -80,9 +82,13 @@
 
 #define SENDERR(_x) do { error = -(_x); goto errlab; } while (0)
 
+#if 0
 #ifndef SOCKOPS_WRAPPED
 #define SOCKOPS_WRAPPED(name) name
 #endif /* SOCKOPS_WRAPPED */
+#endif
+
+extern struct proto_ops SOCKOPS_WRAPPED(pfkey_ops);
 
 #ifdef NET_26
 static rwlock_t pfkey_sock_lock = RW_LOCK_UNLOCKED;
@@ -124,7 +130,6 @@ struct net_proto_family pfkey_family_ops = {
 };
 
 struct proto_ops SOCKOPS_WRAPPED(pfkey_ops) = {
-#ifdef NETDEV_23
         owner:          THIS_MODULE,
 	family:		PF_KEY,
 	release:	pfkey_release,
@@ -142,31 +147,10 @@ struct proto_ops SOCKOPS_WRAPPED(pfkey_ops) = {
 	sendmsg:	pfkey_sendmsg,
 	recvmsg:	pfkey_recvmsg,
 	mmap:		sock_no_mmap,
-#else /* NETDEV_23 */
-	PF_KEY,
-	sock_no_dup,
-	pfkey_release,
-	sock_no_bind,
-	sock_no_connect,
-	sock_no_socketpair,
-	sock_no_accept,
-	sock_no_getname,
-	datagram_poll,
-	sock_no_ioctl,
-	sock_no_listen,
-	pfkey_shutdown,
-	sock_no_setsockopt,
-	sock_no_getsockopt,
-	sock_no_fcntl,
-	pfkey_sendmsg,
-	pfkey_recvmsg
-#endif /* NETDEV_23 */
 };
 
-#ifdef NETDEV_23
 #include <linux/smp_lock.h>
 SOCKOPS_WRAP(pfkey, PF_KEY);
-#endif  /* NETDEV_23 */
 
 #ifdef NET_26
 static void pfkey_sock_list_grab(void)
@@ -565,8 +549,6 @@ pfkey_destroy_socket(struct sock *sk)
 int
 pfkey_upmsg(struct socket *sock, struct sadb_msg *pfkey_msg)
 {
-	int error = 0;
-	struct sk_buff * skb = NULL;
 	struct sock *sk;
 
 	if(sock == NULL) {
@@ -584,6 +566,13 @@ pfkey_upmsg(struct socket *sock, struct sadb_msg *pfkey_msg)
 	}
 
 	sk = sock->sk;
+	return pfkey_upmsgsk(sk, pfkey_msg);
+}
+int
+pfkey_upmsgsk(struct sock *sk, struct sadb_msg *pfkey_msg)
+{
+	int error = 0;
+	struct sk_buff * skb = NULL;
 
 	if(sk == NULL) {
 		KLIPS_PRINT(debug_pfkey,
@@ -720,7 +709,7 @@ pfkey_create(struct socket *sock, int protocol)
 
 	sk->sk_destruct = NULL;
 	sk->sk_reuse = 1;
-	sock->ops = &pfkey_ops;
+	sock->ops = &SOCKOPS_WRAPPED(pfkey_ops);
 
 	sk->sk_family = PF_KEY;
 /*	sk->num = protocol; */
