@@ -32,7 +32,9 @@
 #ifdef CONFIG_KLIPS_DEBUG
 extern int       debug_ah;
 extern int       debug_esp;
+extern int       debug_mast;
 extern int       debug_tunnel;
+extern int       debug_xmit;
 extern int       debug_eroute;
 extern int       debug_spi;
 extern int       debug_radij;
@@ -70,6 +72,8 @@ enum {
 	NET_IPSEC_INBOUND_POLICY_CHECK=14,
 	NET_IPSEC_TOS=15,
 	NET_IPSEC_REGRESS_PFKEY_LOSSAGE=16,
+	NET_IPSEC_DEBUG_MAST=17,
+	NET_IPSEC_DEBUG_XMIT=18,
 };
 
 static ctl_table ipsec_table[] = {
@@ -93,6 +97,15 @@ static ctl_table ipsec_table[] = {
          .proc_handler = &proc_dointvec,
        },
 
+        { .ctl_name = NET_IPSEC_DEBUG_MAST,
+         .procname = "debug_mast",
+         .data     = &debug_mast,
+          .maxlen   = sizeof(int),
+         .mode     = 0644,
+         .child    = NULL,
+         .proc_handler = &proc_dointvec,
+       },
+
         { .ctl_name = NET_IPSEC_DEBUG_TUNNEL,
          .procname = "debug_tunnel",
          .data     = &debug_tunnel,
@@ -102,6 +115,15 @@ static ctl_table ipsec_table[] = {
          .proc_handler = &proc_dointvec,
        },
 
+        { .ctl_name = NET_IPSEC_DEBUG_XMIT,
+         .procname = "debug_xmit",
+         .data     = &debug_xmit,
+          .maxlen   = sizeof(int),
+         .mode     = 0644,
+         .child    = NULL,
+         .proc_handler = &proc_dointvec,
+       },
+
         { .ctl_name = NET_IPSEC_DEBUG_EROUTE,
          .procname = "debug_eroute",
          .data     = &debug_eroute,
@@ -178,8 +200,12 @@ static ctl_table ipsec_table[] = {
 	  sizeof(int), 0644, NULL, .proc_handler = &proc_dointvec},    
 	{ NET_IPSEC_DEBUG_ESP, "debug_esp", &debug_esp,
 	  sizeof(int), 0644, NULL, .proc_handler = &proc_dointvec},    
+	{ NET_IPSEC_DEBUG_MAST, "debug_mast", &debug_mast,
+	  sizeof(int), 0644, NULL, .proc_handler = &proc_dointvec},    
 	{ NET_IPSEC_DEBUG_TUNNEL, "debug_tunnel", &debug_tunnel,
 	  sizeof(int), 0644, NULL, .proc_handler = &proc_dointvec},    
+	{ NET_IPSEC_DEBUG_TUNNEL, "debug_xmit", &debug_xmit,
+	  sizeof(int), 0644, NULL, .proc_handler = &proc_dointvec},    
 	{ NET_IPSEC_DEBUG_EROUTE, "debug_eroute", &debug_eroute,
 	  sizeof(int), 0644, NULL, .proc_handler = &proc_dointvec},    
 	{ NET_IPSEC_DEBUG_SPI, "debug_spi", &debug_spi,
@@ -328,3 +354,10 @@ void ipsec_sysctl_unregister(void)
 
 #endif /* CONFIG_SYSCTL */
 
+/*
+ *
+ * Local Variables:
+ * c-file-style: "linux"
+ * End:
+ *
+ */
