@@ -19,6 +19,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
+#include <errno.h>
 #include <dirent.h>
 #include <time.h>
 #include <sys/types.h>
@@ -764,7 +765,11 @@ load_acerts(void)
 	}
     }
     /* restore directory path */
-    chdir(save_dir);
+    if(!chdir(save_dir)) {
+	int e = errno;
+	openswan_log("Changing back to directory '%s' failed - (%d %s)",
+		save_dir, e, strerror(e));
+    }
 }
 
 /*
