@@ -2076,10 +2076,10 @@ find_host_connection2(const char *func
     struct connection *c;
     char mebuf[ADDRTOT_BUF], himbuf[ADDRTOT_BUF];
     DBG(DBG_CONTROLMORE,
-	DBG_log("find_host_connection called from %s, me=%s:%d him=%s:%d policy=%s", func
+	DBG_log("find_host_connection2 called from %s, me=%s:%d him=%s:%d policy=%s", func
 		, (addrtot(me,  0, mebuf,  sizeof(mebuf)),mebuf),   my_port
-		, (addrtot(him, 0, himbuf, sizeof(himbuf)),himbuf), his_port
-		, bitnamesof(sa_policy_bit_names, policy)));
+		, him ?  (addrtot(him, 0, himbuf, sizeof(himbuf)),himbuf) : "%any"
+		, his_port , bitnamesof(sa_policy_bit_names, policy)));
     c = find_host_pair_connections(__FUNCTION__, me, my_port, him, his_port);
 
     if (policy != LEMPTY) {
@@ -2451,7 +2451,7 @@ is_virtual_net_used(struct connection *c, const ip_subnet *peer_net, const struc
 				 , enum_name(&connection_kind_names, d->kind)
 				 , buf);
 
-		    if(!kernel_ops->overlap_supported) {
+		    if(!kernel_overlap_supported()) {
 			openswan_log("Kernel method '%s' does not support overlapping IP ranges"
 				     , kernel_if_name());
 			return TRUE;
