@@ -1993,15 +1993,17 @@ quick_inI1_outR1_cryptocontinue1(struct pluto_crypto_req_cont *pcrc
 	dh.md=md;
 
 	e = quick_inI1_outR1_cryptotail(&dh, NULL);
+	if(e == STF_OK) {
 
-	if(dh.md != NULL) {
-	    /* note: use qke-> pointer */
-	    complete_v1_state_transition(&qke->md, e);
-	    if(dh.md) release_md(qke->md);
+		if(dh.md != NULL) {
+	    		/* note: use qke-> pointer */
+	    		complete_v1_state_transition(&qke->md, e);
+	    		if(dh.md)
+				release_md(qke->md);
+		}
 	}
     }
     reset_cur_state();
-	
 }
 
 static void
@@ -2029,10 +2031,12 @@ quick_inI1_outR1_cryptocontinue2(struct pluto_crypto_req_cont *pcrc
     set_suspended(st, NULL);
 
     e = quick_inI1_outR1_cryptotail(dh, r);
-
-    if(dh->md != NULL) {
-	complete_v1_state_transition(&dh->md, e);
-	if(dh->md) release_md(dh->md);
+    if(e == STF_OK) {
+    	if(dh->md != NULL) {
+		complete_v1_state_transition(&dh->md, e);
+		if(dh->md) 
+			release_md(dh->md);
+	}
     }
 
     reset_cur_state();
