@@ -24,6 +24,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
+#include <errno.h>
 #include <dirent.h>
 #include <time.h>
 #include <limits.h>
@@ -290,8 +291,8 @@ store_x509certs(x509cert_t **firstcert, bool strict)
 	{
 	    DBG(DBG_X509 | DBG_PARSING,
 		DBG_log("public key validated")
-	    )
-	    add_x509_public_key(cert, valid_until, DAL_SIGNED);
+		);
+	    add_x509_public_key(NULL, cert, valid_until, DAL_SIGNED);
 	}
 	else
 	{
@@ -461,7 +462,11 @@ load_crls(void)
 	}
     }
     /* restore directory path */
-    chdir(save_dir);
+    if(!chdir(save_dir)) {
+        int e = errno;
+        openswan_log("Changing back to directory '%s' failed - (%d %s)",
+                save_dir, e, strerror(e));
+    } 
 }
 
 /*
