@@ -576,9 +576,6 @@ pcap_filter() {
 	FILTER="$FILTER | sed -f $FIXUPDIR/tcpdump-three-eight.sed"
     fi
 
-    PATH=$PATH:../../klips/fixups
-    export PATH
-
     if [ -n "${OUTPUT-}" ]
     then
 	rm -f OUTPUT${KLIPS_MODULE}/${OUTPUT}.txt
@@ -1120,9 +1117,15 @@ complibtest() {
     elif [ -f ${OPENSWANSRCDIR}/lib/libopenswan/$testsrc ]
     then
         FILE=${OPENSWANSRCDIR}/lib/libopenswan/$testsrc
+    elif [ -f ${OPENSWANSRCDIR}/linux/net/klips/$testsrc ]
+    then
+        FILE=${OPENSWANSRCDIR}/linux/net/klips/$testsrc
     elif [ -f ${OPENSWANSRCDIR}/linux/lib/libopenswan/$testsrc ]
     then
         FILE=${OPENSWANSRCDIR}/linux/lib/libopenswan/$testsrc
+    elif [ -f ${OPENSWANSRCDIR}/linux/lib/libfreeswan/$testsrc ]
+    then
+        FILE=${OPENSWANSRCDIR}/linux/lib/libfreeswan/$testsrc
     elif [ -f ${OPENSWANSRCDIR}/linux/net/ipsec/$testsrc ]
     then
         FILE=${OPENSWANSRCDIR}/linux/net/ipsec/$testsrc
@@ -1177,6 +1180,7 @@ libtest() {
 	    ${ECHO} "   "Running $testobj
 	    ( ulimit -c unlimited; cd lib-$testobj && eval ../$testobj ${UNITTESTARGS} >OUTPUT${KLIPS_MODULE}/$testobj.txt 2>&1 )
 
+
 	    stat=$?
 	    ${ECHO} "   "Exit code $stat
 	    if [ $stat -gt 128 ]
